@@ -42,12 +42,15 @@ from .api_pb2 import (  # type: ignore
     ListEntitiesLightResponse,
     ListEntitiesNumberResponse,
     ListEntitiesRequest,
+    ListEntitiesSelectResponse,
     ListEntitiesSensorResponse,
     ListEntitiesServicesResponse,
     ListEntitiesSwitchResponse,
     ListEntitiesTextSensorResponse,
     NumberCommandRequest,
     NumberStateResponse,
+    SelectCommandRequest,
+    SelectStateResponse,
     SensorStateResponse,
     SubscribeHomeassistantServicesRequest,
     SubscribeHomeAssistantStateResponse,
@@ -90,6 +93,8 @@ from .model import (
     LogLevel,
     NumberInfo,
     NumberState,
+    SelectInfo,
+    SelectState,
     SensorInfo,
     SensorState,
     SwitchInfo,
@@ -219,6 +224,7 @@ class APIClient:
             ListEntitiesFanResponse: FanInfo,
             ListEntitiesLightResponse: LightInfo,
             ListEntitiesNumberResponse: NumberInfo,
+            ListEntitiesSelectResponse: SelectInfo,
             ListEntitiesSensorResponse: SensorInfo,
             ListEntitiesSwitchResponse: SwitchInfo,
             ListEntitiesTextSensorResponse: TextSensorInfo,
@@ -262,6 +268,7 @@ class APIClient:
             FanStateResponse: FanState,
             LightStateResponse: LightState,
             NumberStateResponse: NumberState,
+            SelectStateResponse: SelectState,
             SensorStateResponse: SensorState,
             SwitchStateResponse: SwitchState,
             TextSensorStateResponse: TextSensorState,
@@ -274,7 +281,8 @@ class APIClient:
             if isinstance(msg, CameraImageResponse):
                 data = image_stream.pop(msg.key, bytes()) + msg.data
                 if msg.done:
-                    on_state(CameraState.from_pb(msg))
+                    # Return CameraState with the merged data
+                    on_state(CameraState(key=msg.key, data=data))
                 else:
                     image_stream[msg.key] = data
                 return
@@ -374,13 +382,15 @@ class APIClient:
             if stop:
                 req.stop = stop
         else:
-            req.has_legacy_command = True
             if stop:
                 req.legacy_command = LegacyCoverCommand.STOP
+                req.has_legacy_command = True
             elif position == 1.0:
                 req.legacy_command = LegacyCoverCommand.OPEN
-            else:
+                req.has_legacy_command = True
+            elif position == 0.0:
                 req.legacy_command = LegacyCoverCommand.CLOSE
+                req.has_legacy_command = True
         assert self._connection is not None
         await self._connection.send_message(req)
 
@@ -530,6 +540,15 @@ class APIClient:
         assert self._connection is not None
         await self._connection.send_message(req)
 
+    async def select_command(self, key: int, state: str) -> None:
+        self._check_authenticated()
+
+        req = SelectCommandRequest()
+        req.key = key
+        req.state = state
+        assert self._connection is not None
+        await self._connection.send_message(req)
+
     async def execute_service(
         self, service: UserService, data: ExecuteServiceDataType
     ) -> None:
