@@ -168,9 +168,9 @@ class CoverState(EntityState):
     )
 
     def is_closed(self, api_version: APIVersion) -> bool:
-        if api_version >= APIVersion(1, 1):
-            return self.position == 0.0
-        return self.legacy_state == LegacyCoverState.CLOSED
+        if api_version < APIVersion(1, 1):
+            return self.legacy_state == LegacyCoverState.CLOSED
+        return self.position == 0.0
 
 
 # ==================== FAN ====================
@@ -236,6 +236,12 @@ class SensorStateClass(APIIntEnum):
     MEASUREMENT = 1
 
 
+class LastResetType(APIIntEnum):
+    NONE = 0
+    NEVER = 1
+    AUTO = 2
+
+
 @dataclass(frozen=True)
 class SensorInfo(EntityInfo):
     icon: str = ""
@@ -246,6 +252,9 @@ class SensorInfo(EntityInfo):
     state_class: Optional[SensorStateClass] = converter_field(
         default=SensorStateClass.NONE, converter=SensorStateClass.convert
     )
+    last_reset_type: Optional[LastResetType] = converter_field(
+        default=LastResetType.NONE, converter=LastResetType.convert
+    )
 
 
 @dataclass(frozen=True)
@@ -286,7 +295,7 @@ class CameraInfo(EntityInfo):
 
 @dataclass(frozen=True)
 class CameraState(EntityState):
-    image: bytes = field(default_factory=bytes)
+    data: bytes = field(default_factory=bytes)
 
 
 # ==================== CLIMATE ====================
@@ -398,7 +407,7 @@ class ClimateState(EntityState):
     )
     custom_fan_mode: str = ""
     preset: Optional[ClimatePreset] = converter_field(
-        default=ClimatePreset.HOME, converter=ClimatePreset.convert
+        default=ClimatePreset.NONE, converter=ClimatePreset.convert
     )
     custom_preset: str = ""
 
@@ -423,6 +432,19 @@ class NumberState(EntityState):
     missing_state: bool = False
 
 
+# ==================== SELECT ====================
+@dataclass(frozen=True)
+class SelectInfo(EntityInfo):
+    icon: str = ""
+    options: List[str] = converter_field(default_factory=list, converter=list)
+
+
+@dataclass(frozen=True)
+class SelectState(EntityState):
+    state: str = ""
+    missing_state: bool = False
+
+
 COMPONENT_TYPE_TO_INFO: Dict[str, Type[EntityInfo]] = {
     "binary_sensor": BinarySensorInfo,
     "cover": CoverInfo,
@@ -434,6 +456,7 @@ COMPONENT_TYPE_TO_INFO: Dict[str, Type[EntityInfo]] = {
     "camera": CameraInfo,
     "climate": ClimateInfo,
     "number": NumberInfo,
+    "select": SelectInfo,
 }
 
 
